==> apache-hop-2.3.0-src.tar.gz: apache-hop-2.3.0/rap/src/main/java/org/apache/hop/ui/core/widget/svg/SvgLabelListenerImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.ui.core.widget.svg;

import org.apache.commons.io.IOUtils;
import org.apache.hop.ui.hopgui.ISingletonProvider;
import org.eclipse.rap.rwt.SingletonUtil;
import org.eclipse.rap.rwt.scripting.ClientListener;

import java.io.IOException;
import java.nio.charset.StandardCharsets;

public class SvgLabelListenerImpl extends ClientListener implements ISingletonProvider {

  @Override
  public Object getInstanceInternal() {
    return SingletonUtil.getSessionInstance(SvgLabelListenerImpl.class);
  }

  public SvgLabelListenerImpl() {
    super(getText());
  }

  private static String getText() {
    String canvasScript = null;
    try {
      canvasScript =
          IOUtils.toString(
              SvgLabelListenerImpl.class.getResourceAsStream("svg-label.js"), StandardCharsets.UTF_8);
    } catch (IOException e1) {
      e1.printStackTrace();
    }
    return canvasScript;
  }
}

==> apache-hop-2.15.0-src.tar.gz: apache-hop-2.15.0/rap/src/main/java/org/apache/hop/ui/core/widget/svg/SvgLabelListenerImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.ui.core.widget.svg;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import org.apache.commons.io.IOUtils;
import org.apache.hop.ui.hopgui.ISingletonProvider;
import org.eclipse.rap.rwt.SingletonUtil;
import org.eclipse.rap.rwt.scripting.ClientListener;

public class SvgLabelListenerImpl extends ClientListener implements ISingletonProvider {

  @Override
  public Object getInstanceInternal() {
    return SingletonUtil.getSessionInstance(SvgLabelListenerImpl.class);
  }

  public SvgLabelListenerImpl() {
    super(getText());
  }

  private static String getText() {
    String canvasScript = null;
    try {
      canvasScript =
          IOUtils.toString(
              SvgLabelListenerImpl.class.getResourceAsStream("svg-label.js"),
              StandardCharsets.UTF_8);
    } catch (IOException e1) {
      e1.printStackTrace();
    }
    return canvasScript;
  }
}
